@@ -1,9 +1,9 @@
 package File::Edit::Portable;
-use 5.012;
+use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Carp;
 
@@ -53,7 +53,13 @@ sub write {
     my $contents = $self->{contents};
     my $recsep = $self->{custom_recsep};
 
-    return if ! $file;
+    if (! $file){
+        croak "write() requires a file to be passed in!";
+    }
+
+    if (! @$contents){
+        croak "write() requires an array reference of contents to write!";
+    }
 
     $file = $copy if $copy;
 
@@ -143,7 +149,7 @@ File::Edit::Portable - Read and write files while keeping the original line-endi
 
     push @contents, 'new line 1', 'new line 2';
 
-    $rw->write(file => 'file.txt', contents => \@contents);
+    $rw->write(contents => \@contents);
 
     # get the record separator for a file
 
@@ -151,7 +157,7 @@ File::Edit::Portable - Read and write files while keeping the original line-endi
 
     # override the found line ending with a custom one 
 
-    $rw->write(file => 'file', recsep => "\r\n");
+    $rw->write(recsep => "\r\n", contents => \@contents);
 
 =head1 DESCRIPTION
 
@@ -171,14 +177,14 @@ Returns a new C<File::Edit::Portable> object.
 
 =head2 C<read>
 
-Opens a file and extracts its contents, returning an array of the file's contents where each line of the file is a separate element in the array.
+Opens a file and extracts its contents, returning an array of the file's contents where each line of the file is a separate element in the array (line endings have been stripped off).
 
 Parameters: C<file =E<gt> 'filename'>
 
 
 =head2 C<write>
 
-Writes the data back to the original file, or alternately a copy of the file. Returns 1 on success.
+Writes the data back to the original file, or alternately a copy of the file. Returns 1 on success. If you inadvertantly append newlines to the new elements of the contents array, we'll strip them off before appending the real newlines.
 
 Parameters: 
 
